// An example program that blinks the LEDs on the VS1000 developer board.
// The LEDs are connected to SI and SO pins, which are also controllable
// as GPIO pins.

/* For free support for VSIDE, please visit www.vsdsp-forum.com */


#include <vs1000.h>

#define LED1 (1<<2) /* Led 1 is at GPIO1[2] (pin 24) */
#define LED2 (1<<3) /* Led 2 is at GPIO1[3] (pin 25) */


/// Busy wait i hundreths of second at 12 MHz clock
auto void BusyWaitHundreths(u_int16 i) {
	while (i--) {
		BusyWait10(); // Rom function, busy loop 10ms at 12MHz
	}
}


void main(void) {
	// Set GPIO1 pins' mode (peripheral or gpio)
	PERIP(GPIO1_MODE) = 0x30; /* RX, TX are peripherals (1) , SPI is GPIO (0) */
	// Set GPIO1 pins' direction (input or output)
	PERIP(GPIO1_DDR) = 0x0c;	/* SI and SO pins (GPIO1[3:2]) are outputs (1) */

	while (1) {
		
		PERIP(GPIO1_ODATA) |= LED1;	 // Switch LED 1 on
		PERIP(GPIO1_ODATA) &= ~LED2; // Switch LED 2 off
		
		BusyWaitHundreths(50);
		
		PERIP(GPIO1_ODATA) &= ~LED1; // Switch LED 1 off
		PERIP(GPIO1_ODATA) |= LED2;	 // Switch LED 2 on
		
		BusyWaitHundreths(50);
	}
}
